//::///////////////////////////////////////////////
//:: Summon Elemental
//:: mt_f0_reservesommonelemental
//:: Purpose: Reserve Feat: Summon Elemental
//:: Created By: Joshua Kalis (Greg)
//:: Created On: October 15, 2015
//:: Description: Summon a small, medium or large elemental based on if they character has a required elemental summoning spell memorized.
//:: Fundamental Mystery
//:: Creates standard darkness
//::
//:: You create an area of darkness.
//:://////////////////////////////////////////////

#include "X0_I0_SPELLS"
#include "x2_inc_spellhook" 

void main()
{
    if (!X2PreSpellCastCode())
    {
	// If code within the PreSpellCastHook (i.e. UMD) reports FALSE, do not run this spell
        return;
    }

	// Determine the type of the elemental. Start with even 25% chance for each and then modify if they have any of the elemental reserve feats.
	int nAcid = 25;
	int nAir = 25;
	int nFire = 25;
	int nWater = 25;
	
    if (GetHasFeat(3092)) // Acidic Splatter
    {
        nAcid = nAcid + 15;
		nAir = nAir - 5;
		nFire = nFire - 5;
		nWater = nWater - 5;
    }	
	else {
		if (GetHasFeat(3093)) // Clap of Thunder
		{
			nAcid = nAcid - 5;
			nAir = nAir + 15;
			nFire = nFire - 5;
			nWater = nWater - 5;
		}	
		else {
			if (GetHasFeat(3094)) // Fiery Burst
			{
				nAcid = nAcid - 5;
				nAir = nAir - 5;
				nFire = nFire + 15;
				nWater = nWater - 5;
			}	
			else {
				if (GetHasFeat(3101)) // Breath of Winter
				{
					nAcid = nAcid - 5;
					nAir = nAir - 5;
					nFire = nFire - 5;
					nWater = nWater + 15;
				}	
			}
		}
	}

	int nRandom1 = Random(nAcid);
	int nRandom2 = Random(nAir);
	int nRandom3 = Random(nFire);
	int nRandom4 = Random(nWater);
	int nElementalType = 0;
	
	if(nRandom1 >= nRandom2 && nRandom1 >= nRandom3 && nRandom1 >= nRandom4)
	{
		// Use earth elemental.		
		nElementalType = 1;
	}
	else 
	{
		if(nRandom2 >= nRandom1 && nRandom2 >= nRandom3 && nRandom2 >= nRandom4)
		{
			// Use air elemental.
			nElementalType = 2;
		}
		else 
		{
			if(nRandom3 >= nRandom1 && nRandom3 >= nRandom2 && nRandom3 >= nRandom4)
			{
				// Use fire elemental.
				nElementalType = 3;
			}
			else 
			{
				// Use water elemental.
				nElementalType = 4;
			}
		}
	}
	
	// Determine the power of the elemental.
	int nLevel = 0; // start out you can't summon at all
	
	// Collect the spells that summon elementals. Summon s/m/l elemental based on most powerful spell memorized.
	if (GetHasSpell(96))
		nLevel = 1;
	if (GetHasSpell(180))
		nLevel = 1;

	if (GetHasSpell(128))
		nLevel = 2;
	if (GetHasSpell(181))
		nLevel = 2;
	if (GetHasSpell(451))
		nLevel = 2;
		
	if (GetHasSpell(48))
		nLevel = 3;
	if (GetHasSpell(63))
		nLevel = 3;
	if (GetHasSpell(69))
		nLevel = 3;
	if (GetHasSpell(182))
		nLevel = 3;
	if (GetHasSpell(1078))
		nLevel = 3;
		
	if (GetHasSpell(2429) || GetHasSpell(2430) || GetHasSpell(2431)) 
	{
		nLevel = 3;
		
		// Use water elemental.
		nElementalType = 4;
	}
	if (GetHasSpell(2432) || GetHasSpell(2433) || GetHasSpell(2434)) 
	{
		nLevel = 3;
		
		// Use fire elemental.
		nElementalType = 3;
	}
	if (GetHasSpell(2438) || GetHasSpell(2439) || GetHasSpell(2440)) 
	{
		nLevel = 3;
		
		// Use air elemental.
		nElementalType = 2;
	}
	if (GetHasSpell(2435) || GetHasSpell(2436) || GetHasSpell(2437)) 
	{
		nLevel = 3;
		
		// Use earth elemental.		
		nElementalType = 1;
	}

	string sSummon = "";
	
	if(nLevel == 1)
	{
		// Only small water elementals exist right now, make blueprints for the others.
		if(nElementalType == 1)
			sSummon = "c_elmearthsmall";
		else if(nElementalType == 1)
			sSummon = "c_elmairsmall";
		else if(nElementalType == 1)
			sSummon = "c_elmfiresmall";
		else if(nElementalType == 1)
			sSummon = "c_elmwatersmall";
		else
			nLevel = 0;		
	}
	if(nLevel == 2)
	{
		if(nElementalType == 1)
			sSummon = "c_elmearth";
		else if(nElementalType == 1)
			sSummon = "c_elmair";
		else if(nElementalType == 1)
			sSummon = "c_elmfire";
		else if(nElementalType == 1)
			sSummon = "c_elmwater";
		else
			nLevel = 0;		
	}
	if(nLevel == 2)
	{
		if(nElementalType == 1)
			sSummon = "c_elmearthlarge";
		else if(nElementalType == 1)
			sSummon = "c_elmairlarge";
		else if(nElementalType == 1)
			sSummon = "c_elmfirelarge";
		else if(nElementalType == 1)
			sSummon = "c_elmwaterlarge";
		else
			nLevel = 0;		
	}
						
	if (nLevel == 0)
	{
		SendMessageToPC(OBJECT_SELF,"You do not have any valid spells left that can trigger this ability.");	
		return;	
	}
	else
	{
		int nSpellID = GetSpellId();

		int nDuration = GetCasterLevel(OBJECT_SELF) + 3;
		effect eSummonedMonster = EffectSummonCreature(sSummon, VFX_FNF_SUMMON_MONSTER_1);

		ApplyEffectAtLocation(DURATION_TYPE_TEMPORARY, eSummonedMonster, GetSpellTargetLocation(), RoundsToSeconds(nDuration));
		//DelayCommand(6.0f, BuffSummons(OBJECT_SELF));
	}
}