//::///////////////////////////////////////////////
//:: Avascular Mass
//:: mt_s0_avascularmass
//:: Purpose: 8th level necromancy spell
//:: Created By: Joshua Kalis (Greg)
//:: Created On: Nov 11, 2015
//:: Description:
//:: As avasculate but also 20' bloody sticky situation
//:://////////////////////////////////////////////

/*
	Avasculate
	Necromancy [Death, Evil]
	Level: sorceror/wizard 7
	Components: V,S
	Range: Close
	Duration: Instantaneous
	Saving Throw: Fortitude partial
	Spell Resistance: Yes
	 
	You must succeed on a ranged touch attack with 
	the ray to strike a target.  If the attack succeeds, 
	the subject is reduced to half of its current hit 
	points and stunned for 1 round.  On a successful 
	Fortitude saving throw, the subject is not stunned.
*/
//:://////////////////////////////////////////////
//:: Created By: Patrick Mills
//:: Created On: 12.06.2006
//:://////////////////////////////////////////////
//:: AFW-OEI 07/10/2007: NX1 VFX
//:: RPGplayer1 02/04/2009: Made SpellCastAt event hostile, so that caster drops invisibility properly
//:: RPGplayer1 02/05/2009: Signal SpellCastAt event regardless of TouchAttack success

#include "nw_i0_spells"
#include "x2_inc_spellhook" 
#include "nwn2_inc_metmag"


void main()
{
    /*
      Spellcast Hook Code
      Added 2003-07-07 by Georg Zoeller
      If you want to make changes to all spells,
      check x2_inc_spellhook.nss to find out more

    */

    if (!X2PreSpellCastCode())
    {
    // If code within the PreSpellCastHook (i.e. UMD) reports FALSE, do not run this spell
        return;
    }

// End of Spell Cast Hook

//Major variables
	object 	oTarget 	= 	GetSpellTargetObject();
	object 	oCaster 	= 	OBJECT_SELF;
	int     nCasterLvl  =   GetCasterLevel(oCaster);
	int		nDam;
	int     nSpellSaveDC =  GetSpellSaveDC();
	effect	eStun		=	EffectStunned();
	effect	eDam;
	effect 	eVis		=	EffectVisualEffect(VFX_HIT_SPELL_AVASCULATE);
	effect	eVisStun	=	EffectVisualEffect(VFX_DUR_STUN);
	effect	eLink;
	effect	eLinkStun;	
	float	fDur		=	RoundsToSeconds(1);
	float   fSecondDur  =   RoundsToSeconds(nCasterLvl);

//Determine damage
			nDam		=	GetCurrentHitPoints(oTarget)/2;
			eDam		=	EffectDamage(nDam, DAMAGE_TYPE_MAGICAL, DAMAGE_POWER_NORMAL, TRUE);	// AFW-OEI 07/10/2007: Ignore all resistances.
			
	
//Link up effects
			eLink		=	EffectLinkEffects(eDam, eVis);
			eLinkStun	=	EffectLinkEffects(eStun, eVisStun);
			
//Determine duration of the stun effect
			fDur		=	ApplyMetamagicDurationMods(fDur);
			fSecondDur	=	ApplyMetamagicDurationMods(fSecondDur);

//Validate target and apply effects
//Target Discrimination

// Spell Save
    if (GetHasFeat(5028)) // If have archmage SP+3, add 3 more.
    {
        nSpellSaveDC = (nSpellSaveDC + 3);
    }	
    else if (GetHasFeat(5027)) // If have archmage SP+2, add 2 more.
    {
        nSpellSaveDC = (nSpellSaveDC + 2);
    }	
    else if (GetHasFeat(5026)) // If have archmage SP+1, add 1 more.
    {
        nSpellSaveDC = (nSpellSaveDC + 1);
    }	
 
	if (GetIsObjectValid(oTarget))
	{
		if (spellsIsTarget(oTarget, SPELL_TARGET_STANDARDHOSTILE, oCaster))
		{	
			//Target is valid, cast spell and then run spell resistance and saving throw before applying effect
			SignalEvent(oTarget, EventSpellCastAt(OBJECT_SELF, 1032, TRUE));
			
			//Performed ranged touch attack
			if (TouchAttackRanged(oTarget, TRUE))
			{
				// Apply primary effect, same as avasculate.
				if (!MyResistSpell(oCaster, oTarget))
				{
					//This is a death spell, determine immunity and drop the target if they are immune
					if (GetIsImmune(oTarget,IMMUNITY_TYPE_DEATH, oCaster))
					{
						//print an immunity string
						return;
					}
					if (MySavingThrow(SAVING_THROW_FORT, oTarget, nSpellSaveDC, SAVING_THROW_TYPE_DEATH, oCaster))
					{
						ApplyEffectToObject(DURATION_TYPE_INSTANT, eDam, oTarget);
					}
					else
					{
						ApplyEffectToObject(DURATION_TYPE_INSTANT, eDam, oTarget);
						ApplyEffectToObject(DURATION_TYPE_TEMPORARY, eLinkStun, oTarget, fDur);
					}
				}
				ApplyEffectToObject(DURATION_TYPE_INSTANT, eVis, oTarget);
				
				// Now apply secondary effect.
				//
			    effect eExplode = EffectVisualEffect(VFX_FNF_IMPLOSION); 			    
			    eVis = EffectVisualEffect(VFX_IMP_HEAD_EVIL);
				
			    //Get the spell target location as opposed to the spell target.
			    location lTarget = GetSpellTargetLocation();
			
			    //Apply the fireball explosion at the location captured above.
			    /* Brock H. - OEI 03/03/06 -- Handled by the ImpactSEF column in the spells.2da
			    ApplyEffectAtLocation(DURATION_TYPE_INSTANT, eExplode, lTarget);*/
			
			    //Declare the spell shape, size and the location.  Capture the first target object in the shape.
			    oTarget = GetFirstObjectInShape(SHAPE_SPHERE, RADIUS_SIZE_HUGE, lTarget, TRUE, OBJECT_TYPE_CREATURE);
			    //Cycle through the targets within the spell shape until an invalid object is captured.
			    while (GetIsObjectValid(oTarget))
			    {
			        if (spellsIsTarget(oTarget, SPELL_TARGET_STANDARDHOSTILE, OBJECT_SELF))
			    	{
						if (MySavingThrow(SAVING_THROW_REFLEX, oTarget, GetSpellSaveDC(), SAVING_THROW_TYPE_DEATH, oCaster))
						{
							effect eStun = EffectStunned();
							ApplyEffectToObject(DURATION_TYPE_TEMPORARY, eStun, oTarget, fSecondDur);
						}
					}
					
			       //Select the next target within the spell shape.
			       oTarget = GetNextObjectInShape(SHAPE_SPHERE, RADIUS_SIZE_HUGE, lTarget, TRUE, OBJECT_TYPE_CREATURE);
			    }	
				
			}			
		}
	}
}
					