//::///////////////////////////////////////////////
//:: IceLance
//:: Created by Reeron on 4-1-08
//:://////////////////////////////////////////////
/*
    You must succeed on a ranged touch attack. If 
    you hit, the icelance deals 6d6 points of damage 
    to the target. Half of this damage is piercing 
    damage; the rest is cold damage. In addition, the 
    target must make a Fortitude save or be stunned 
    for 1d4 rounds.
*/
/////////////////////////////////////////////////////////
//:://////////////////////////////////////////////
//:: 
//:: Reeron modifed on 4-1-08
//:: 
//:: Respects immunity to critical hits.
//:: Added sneak attack damage.
//:: Added check for point blank shot feat.
//:: Now does extra damage if you have the (custom) feat 
//:: Ranged Spell Specialization.
//::
//:://////////////////////////////////////////////

#include "X0_I0_SPELLS"
#include "x2_inc_spellhook"
#include "x2_i0_spells"
#include "nw_i0_spells"
#include "cmi_inc_sneakattack"

void main()
{
    if (!X2PreSpellCastCode())
    {	// If code within the PreSpellCastHook (i.e. UMD) reports FALSE, do not run this spell
        return;
    }
	
    object oTarget = GetSpellTargetObject();
    effect eStun = EffectStunned();
    effect eDur = EffectVisualEffect( VFX_DUR_STUN );
    eStun = EffectLinkEffects( eStun, eDur );

    //--------------------------------------------------------------------------
    // Calculate the duration
    //--------------------------------------------------------------------------
	int nCasterLvl = GetCasterLevel(OBJECT_SELF);
	int nSpellSaveDC = GetSpellSaveDC();
	int nBonus = 0;
	
	nCasterLvl = 1;
	
    if (GetHasFeat(5028)) // If have archmage SP+3, add 3 more.
    {
        nCasterLvl = (nCasterLvl + 3);
        nSpellSaveDC = (nSpellSaveDC + 3);
        nBonus = (nBonus + 3);
    }	
    else if (GetHasFeat(5027)) // If have archmage SP+2, add 2 more.
    {
        nCasterLvl = (nCasterLvl + 2);
        nSpellSaveDC = (nSpellSaveDC + 2);
        nBonus = (nBonus + 2);
    }	
    else if (GetHasFeat(5026)) // If have archmage SP+1, add 1 more.
    {
        nCasterLvl = (nCasterLvl + 1);
        nSpellSaveDC = (nSpellSaveDC + 1);
        nBonus = (nBonus + 1);
    }	
	
    if (GetHasFeat(3101)) // If have winters blast, add 1 more.
    {
        nCasterLvl = (nCasterLvl + 1);
        nSpellSaveDC = (nSpellSaveDC + 1);
        nBonus = (nBonus + 1);
    }	
	
    int nDuration = d4(nCasterLvl);
    int nMetaMagic = GetMetaMagicFeat();
    if (nDuration < 1)
    {
        nDuration = 1;
    }
    if (nMetaMagic & METAMAGIC_EXTEND)
    {
        nDuration = nDuration * 2;
    }

    //--------------------------------------------------------------------------
    // Setup VFX
    //--------------------------------------------------------------------------
    effect eVis = EffectVisualEffect(VFX_HIT_SPELL_ICE);

    if (spellsIsTarget(oTarget, SPELL_TARGET_STANDARDHOSTILE, OBJECT_SELF))
	{
        SignalEvent(oTarget, EventSpellCastAt(OBJECT_SELF, GetSpellId()));
		
        float fDist = GetDistanceToObject(oTarget);
        float fDelay = (fDist/25.0);//(3.0 * log(fDist) + 2.0);
		
		int nTouch = TouchAttackRanged(oTarget, FALSE, nBonus);
		if (nTouch != TOUCH_ATTACK_RESULT_MISS)
        {
            if(!MyResistSpell(OBJECT_SELF, oTarget))
            {
                int nDamage = MaximizeOrEmpower(6,6+nBonus,nMetaMagic);
				if (nTouch == TOUCH_ATTACK_RESULT_CRITICAL && !GetIsImmune(oTarget, IMMUNITY_TYPE_CRITICAL_HIT))
				{ 
					nDamage = MaximizeOrEmpower(6,12 + (nBonus),nMetaMagic); 
				}
				else
				{
					nDamage = nDamage; 
				}
					
				//include sneak attack damage
				if (StringToInt(Get2DAString("cmi_options","Value",CMI_OPTIONS_SneakAttackSpells)))
				{	nDamage += EvaluateSneakAttack(oTarget, OBJECT_SELF);	}
					
                int nDamage2 = nDamage/2;
                int nDamage3 = nDamage-nDamage2;
				
				int nDmgType = DAMAGE_TYPE_COLD;	
				
                effect eDam1 = EffectDamage(nDamage2, DAMAGE_TYPE_PIERCING);
                effect eDam2 = EffectDamage(nDamage3, nDmgType);
                ApplyEffectToObject(DURATION_TYPE_INSTANT, eVis, oTarget);
                ApplyEffectToObject(DURATION_TYPE_INSTANT, eDam1, oTarget);
                ApplyEffectToObject(DURATION_TYPE_INSTANT, eDam2, oTarget);
				
                if (!MySavingThrow(SAVING_THROW_FORT, oTarget, nSpellSaveDC))
                {
                    DelayCommand(fDelay, ApplyEffectToObject(DURATION_TYPE_TEMPORARY, eStun, oTarget, RoundsToSeconds(nDuration)));
                }
				
				if (GetHasFeat(5212,OBJECT_SELF,TRUE)) // Diabolism
				{
					int nLevelDiabolist = GetLevelByClass(96, OBJECT_SELF);
					if(nLevelDiabolist == 10)
						nDamage = 3;
					else if(nLevelDiabolist == 5)
						nDamage = 2;
					else
						nDamage = 1;	
					
	                effect eDam2 = EffectDamage(nDamage, DAMAGE_TYPE_NEGATIVE);
					ApplyEffectToObject(DURATION_TYPE_INSTANT, eDam2, oTarget);
				}

				if (GetHasFeat(5213,OBJECT_SELF,TRUE)) // Vile Diabolism
				{
					nDamage = 1;
	                effect eDam3 = EffectDamage(nDamage, DAMAGE_TYPE_MAGICAL);
					ApplyEffectToObject(DURATION_TYPE_INSTANT, eDam3, oTarget);
				}						
    	    }
	    }
    }
}