//::///////////////////////////////////////////////
//:: Invocation: Hellfire Blast (Hellfire Warlock Invocation)
//:: mt_s0_invochellfire
//:: Created By: Joshua Kalis (Greg)
//:: Created On: Jan 20, 2008
//:://////////////////////////////////////////////

#include "nw_i0_invocatns"
#include "x2_inc_spellhook" 

int DoHellfireEldritchBlast(object oCaster, object oTarget, int bCalledFromShape, int bDoTouchTest, int nDmgType, int nAllowReflexSave, int nIgnoreResists, int nHalfDmg, int nVFX)
{
    // Default Blast w/no mods
    int nMetaMagic = GetMetaMagicFeat();
	int nHitVFX = VFX_INVOCATION_ELDRITCH_HIT;	// default is Edlritch
	int nTouch;
    //if ( nMetaMagic != METAMAGIC_NONE )
    //if ( !(nMetaMagic & METAMAGIC_ELDRITCH_SHAPES) )
	
	// adjust the VFX according to the essence
    nHitVFX = VFX_INVOCATION_BRIMSTONE_HIT;

    if(bDoTouchTest)
    {
        // AFW-OEI 02/20/2007: Eldritch Master adds +2 to the attack roll.
        int nBonus = 0;
        if (GetHasFeat(FEAT_EPIC_ELDRITCH_MASTER, oCaster))
        {
            nBonus = 3;
        }
    
		nTouch = TouchAttackRanged(oTarget, TRUE, nBonus);
		
        //if ( TouchAttackRanged( oTarget, TRUE, nBonus ) == TOUCH_ATTACK_RESULT_MISS )
		if (nTouch == TOUCH_ATTACK_RESULT_MISS)
        {
            // Failed
            SignalEvent(oTarget, EventSpellCastAt(oCaster, GetSpellId(), TRUE));
            return FALSE;
        }
    }


    // Spell Effects not allowed to stack...
    RemoveEffectsFromSpell(oTarget, GetSpellId());

    effect eBeam = EffectBeam(nVFX, oCaster, BODY_NODE_HAND);
    if (spellsIsTarget(oTarget, SPELL_TARGET_STANDARDHOSTILE, oCaster) == TRUE)
    {
        SignalEvent(oTarget, EventSpellCastAt(oCaster, GetSpellId()));

		// Calculate damage, add +2D6 extra due to power of hellfire.
        int nDmg = GetEldritchBlastDmg(oCaster, oTarget, nAllowReflexSave, nIgnoreResists, nHalfDmg, nTouch) + d6(2);

        if ( nDmg > 0 )  // Make sure wasn't resisted
        {
            //Fire cast spell at event for the specified target
            SignalEvent(oTarget, EventSpellCastAt(oCaster, GetSpellId(), TRUE));

            //Set damage effect
            float fDelay = 0.0;
            effect eDam = EffectDamage(nDmg, nDmgType);
            effect eVis = EffectVisualEffect( nHitVFX );
            
            //Apply the damage effect
            ApplyEffectToObject(DURATION_TYPE_TEMPORARY, eVis, oTarget);
            DelayCommand( fDelay, ApplyEffectToObject(DURATION_TYPE_INSTANT, eDam, oTarget) );

			// We only want to display the beam visual effect if the blast was NOT called from any of the Shape spells; otherwise, the shape will already have been displayed.
			if ( !bCalledFromShape )
			{
            	ApplyEffectToObject(DURATION_TYPE_TEMPORARY,eBeam,oTarget,1.0);
			}
			
            return TRUE;
        }
    }
    return FALSE;
}

void RunEssenceHellfireBlastImpact(object oTarget, object oCaster, int nRoundsLeft)
{
	//SpeakString("RunEssenceBrimstoneBlastImpact(...): Entering function.");	// DEBUG!
	
	// AFW-OEI 07/06/2006: Can't "dispel" fire, so no need to check effects
    //if (GZGetDelayedSpellEffectsExpired(SPELL_I_BRIMSTONE_BLAST, oTarget, oCaster))
    //{
    //    return;
    //}

	
    if ((GetIsDead(oTarget) == FALSE) && (nRoundsLeft > 0))
    {
        int nDC = GetDelayedSpellInfoSaveDC(SPELL_I_BRIMSTONE_BLAST, oTarget, oCaster);

		
        if(!MySavingThrow(SAVING_THROW_REFLEX, oTarget, nDC, SAVING_THROW_TYPE_ALL))
        {
            int nDmg = d6(2);
            effect eDmg = EffectDamage(nDmg,DAMAGE_TYPE_POSITIVE);
            

            ApplyEffectToObject(DURATION_TYPE_INSTANT,eDmg,oTarget);
            //ApplyEffectToObject(DURATION_TYPE_TEMPORARY, eVFX, oTarget, 6.0);	// handled by DoEldritchBlast()

            nRoundsLeft = nRoundsLeft - 1;
            DelayCommand(RoundsToSeconds(1), RunEssenceHellfireBlastImpact(oTarget, oCaster, nRoundsLeft));	// Delay for one more round
        }
        else
        {
            RemoveDelayedSpellInfo(SPELL_I_BRIMSTONE_BLAST, oTarget, oCaster);
            //GZRemoveSpellEffects(SPELL_I_BRIMSTONE_BLAST, oTarget);
        }
    }
}


int DoEssenceHellfireBlast(object oCaster, object oTarget)
{
	//SpeakString("DoEssenceBrimstoneBlast(...): Entering function.");	// DEBUG!
	int nHasSpellEffect = GetHasSpellEffect(GetSpellId(), oTarget);
	int bCalledFromShape = FALSE;
	int bDoTouchTest = FALSE;
	int nAllowReflexSave = FALSE;
	int nHalfDmg = FALSE;
    // First, do Base Effects:
    if ( DoHellfireEldritchBlast(oCaster, oTarget, bCalledFromShape, bDoTouchTest, DAMAGE_TYPE_POSITIVE, nAllowReflexSave, FALSE, nHalfDmg, VFX_INVOCATION_BRIMSTONE_RAY) )
    {
        // Additional Effects: (Combust)
        if (GetObjectType(oTarget) == OBJECT_TYPE_CREATURE)
        {
			
            // Doesn't Stack!
            if (nHasSpellEffect == 1)
            {
                //FloatingTextStrRefOnCreature(100775, OBJECT_SELF, FALSE);
                return FALSE;
            }

            int nCasterLvl = GetCasterLevel(OBJECT_SELF);
            int nRoundsLeft;
            if ( nCasterLvl >= 20 )       { nRoundsLeft = 4; }
            else if ( nCasterLvl >= 15 )  { nRoundsLeft = 3; }
            else if ( nCasterLvl >= 10 )  { nRoundsLeft = 2; }
            else                          { nRoundsLeft = 1; }

            int nDC = GetSpellSaveDC();
            SaveDelayedSpellInfo(SPELL_I_BRIMSTONE_BLAST, oTarget, oCaster, nDC);
			effect eVFX = EffectVisualEffect(894);
			ApplyEffectToObject(DURATION_TYPE_TEMPORARY, eVFX, oTarget, RoundsToSeconds(nRoundsLeft));	
			DelayCommand(RoundsToSeconds(1), RunEssenceBrimstoneBlastImpact(oTarget, oCaster, nRoundsLeft));	// First check should be one round after the blast hit
				
	        return TRUE;
        }
    }
    return FALSE;
}

void main()
{

/* 
  Spellcast Hook Code 
  Added 2003-06-23 by GeorgZ
  If you want to make changes to all spells,
  check x2_inc_spellhook.nss to find out more
  
*/

    if (!X2PreSpellCastCode())
    {
	// If code within the PreSpellCastHook (i.e. UMD) reports FALSE, do not run this spell
        return;
    }

// End of Spell Cast Hook


    //Declare major variables
    object oTarget = GetSpellTargetObject();

    // Additional Effects: (Combust Effect + extra 2D6 damage)
	if(GetHasFeat(5107, OBJECT_SELF))
    	DoEssenceHellfireBlast(OBJECT_SELF, oTarget);
	else {
	}
}