//::///////////////////////////////////////////////
//:: Prismatic Deluge
//:: mt_s0_prismaticdeluge
//:: Created By: Joshua Kalis (Greg)
//:: Created On: Jan 25, 2008
//:://////////////////////////////////////////////

#include "X0_I0_SPELLS"
#include "x2_inc_spellhook" 
//#include "nw_s0_prisspray"

const int PS_EFFECT_FIRE 			= 0;
const int PS_EFFECT_ACID 			= 1;
const int PS_EFFECT_ELECTRICITY 	= 2;
const int PS_EFFECT_POISON 			= 3;
const int PS_EFFECT_PARALYZE		= 4;
const int PS_EFFECT_CONFUSION		= 5;
const int PS_EFFECT_DEATH 			= 6;
const int PS_EFFECT_STONE 			= 7;
const int PS_EFFECT_COUNT 			= 8;

//Set the delay to apply to effects based on the distance to the target
float GetDelayForTarget( object oTarget )
{
	float fDelay = 1.5 + GetDistanceBetween(OBJECT_SELF, oTarget)/20;
	return fDelay;
}

///////////////////////////////////////////////////////////////////////////////
//  ApplyPrismaticEffect
///////////////////////////////////////////////////////////////////////////////
/*  Given a reference integer and a target, this function will apply the effect
    of corresponding prismatic cone to the target.  To have any effect the
    reference integer (nEffect) must be from 1 to 7.*/
///////////////////////////////////////////////////////////////////////////////
//  Created By: Aidan Scanlan On: April 11, 2001
///////////////////////////////////////////////////////////////////////////////

int ApplyPrismaticEffect(int nEffect, object oTarget)
{

    effect 	ePrism;
    effect 	eVis;
    effect 	eDur 	= EffectVisualEffect( VFX_DUR_SPELL_PRISMATIC_SPRAY );
    effect	eLink;
    int 	nDamage = 0;
    int 	nVis 	= 0;
     float 	fDelay	= GetDelayForTarget( oTarget );

    //Based on the random number passed in, apply the appropriate effect and set the visual to
    //the correct constant
    switch(nEffect)
    {
        case PS_EFFECT_FIRE://fire
			{
	            nDamage = 20;
	            nVis = VFX_HIT_SPELL_FIRE;
	            nDamage = GetReflexAdjustedDamage(nDamage, oTarget, JXGetSpellSaveDC(), SAVING_THROW_TYPE_FIRE);
	            ePrism = EffectDamage(nDamage, DAMAGE_TYPE_FIRE);
	            DelayCommand(fDelay, JXApplyEffectToObject(DURATION_TYPE_INSTANT, ePrism, oTarget));
			}
        break;

        case PS_EFFECT_ACID: //Acid
			{
	            nDamage = 40;
	            nVis = VFX_HIT_SPELL_ACID;
	            nDamage = GetReflexAdjustedDamage(nDamage, oTarget, JXGetSpellSaveDC(), SAVING_THROW_TYPE_ACID);
	            ePrism = EffectDamage(nDamage, DAMAGE_TYPE_ACID);
	            DelayCommand(fDelay, JXApplyEffectToObject(DURATION_TYPE_INSTANT, ePrism, oTarget));
			}
        break;

        case PS_EFFECT_ELECTRICITY: //Electricity
			{
	            nDamage = 80;
	            nVis = VFX_HIT_SPELL_LIGHTNING;
	            nDamage = GetReflexAdjustedDamage(nDamage, oTarget, JXGetSpellSaveDC(), SAVING_THROW_TYPE_ELECTRICITY);
	            ePrism = EffectDamage(nDamage, DAMAGE_TYPE_ELECTRICAL);
	            DelayCommand(fDelay, JXApplyEffectToObject(DURATION_TYPE_INSTANT, ePrism, oTarget));
			}
        break;

        case PS_EFFECT_POISON: //Poison
            {
                effect ePoison = EffectPoison(POISON_BEBILITH_VENOM);
				nVis = VFX_HIT_SPELL_POISON;
                DelayCommand(fDelay, JXApplyEffectToObject(DURATION_TYPE_INSTANT, ePoison, oTarget));
            }
        break;

        case PS_EFFECT_PARALYZE: //Paralyze
            {
				nVis = VFX_HIT_SPELL_ENCHANTMENT;
                effect eDur2 = EffectVisualEffect(VFX_DUR_PARALYZED);
				int nSaveDC = JXGetSpellSaveDC();
                if (MySavingThrow(SAVING_THROW_FORT, oTarget, nSaveDC) == 0)
                {
                    ePrism = EffectParalyze(nSaveDC, SAVING_THROW_FORT);
                    eLink = EffectLinkEffects(eDur2, ePrism);
//                    eLink = EffectLinkEffects(eLink, eDur2);
                    DelayCommand(fDelay, JXApplyEffectToObject(DURATION_TYPE_TEMPORARY, eLink, oTarget, RoundsToSeconds(10)));
                }
            }
        break;

        case PS_EFFECT_CONFUSION: //Confusion
            {
                effect eDur = EffectVisualEffect( VFX_DUR_SPELL_CONFUSION );
                ePrism = EffectConfused();
                eLink = EffectLinkEffects(eDur, ePrism);
                //eLink = EffectLinkEffects(eLink, eDur);

                if (!/*Will Save*/ MySavingThrow(SAVING_THROW_WILL, oTarget, JXGetSpellSaveDC(), SAVING_THROW_TYPE_MIND_SPELLS, OBJECT_SELF, fDelay))
                {
                    //nVis = VFX_HIT_SPELL_ENCHANTMENT;
                    DelayCommand(fDelay, JXApplyEffectToObject(DURATION_TYPE_TEMPORARY, eLink, oTarget, RoundsToSeconds(10)));
                }
            }
        break;

        case PS_EFFECT_DEATH: //Death
            {
                if (!/*Will Save*/ MySavingThrow(SAVING_THROW_WILL, oTarget, JXGetSpellSaveDC(), SAVING_THROW_TYPE_DEATH, OBJECT_SELF, fDelay))
                {
                    nVis = VFX_HIT_SPELL_NECROMANCY;
                    ePrism = EffectDeath();
                    DelayCommand(fDelay, JXApplyEffectToObject(DURATION_TYPE_INSTANT, ePrism, oTarget));
                }
            }
        break;

		case PS_EFFECT_STONE: // Flesh to Stone 
			{
                //if (!/*Will Save*/ MySavingThrow(SAVING_THROW_WILL, oTarget, GetSpellSaveDC(), SAVING_THROW_TYPE_DEATH, OBJECT_SELF, fDelay))
                {
					//nVis = VFX_HIT_SPELL_TRANSMUTATION;
				    //object oTarget = GetSpellTargetObject();
				    int nCasterLvl = JXGetCasterLevel(OBJECT_SELF);
				
				    //if (MyResistSpell(OBJECT_SELF,oTarget) <1)
				    {
				    	DelayCommand(fDelay, DoPetrification(nCasterLvl, OBJECT_SELF, oTarget, JXGetSpellId(), JXGetSpellSaveDC()) );
					}
				}
			}
    }
    return nVis;
}

void mainSpell();
void main()
{
	AssignCommand(JXGetCaster(), mainSpell());
}

void mainSpell()
{
    if (!X2PreSpellCastCode())
    {	// If code within the PreSpellCastHook (i.e. UMD) reports FALSE, do not run this spell
        JXPostSpellCastCode();
        return;
    }

	//Declare major variables
	object oTarget = JXGetSpellTargetObject();
	int nCasterLvl = JXGetCasterLevel(OBJECT_SELF);
	
	if (nCasterLvl > 10)
		nCasterLvl = 10;
	int nDamage = d6(nCasterLvl);	
		
	effect eVis;	
	effect eOrbEffect;
	int nDamageType;
	int nSpellId = JXGetSpellId();
	
    //Get the spell target location as opposed to the spell target.
    location lTarget = JXGetSpellTargetLocation();

	// Calculate the damage type.
	nDamageType	= DAMAGE_TYPE_ACID;
	eVis = EffectVisualEffect(VFX_HIT_SPELL_ACID);
		  
    oTarget = GetFirstObjectInShape(SHAPE_SPHERE, RADIUS_SIZE_COLOSSAL, lTarget, TRUE, OBJECT_TYPE_CREATURE | OBJECT_TYPE_DOOR | OBJECT_TYPE_PLACEABLE);

	//Cycle through the targets within the spell shape until an invalid object is captured.
    while (GetIsObjectValid(oTarget))
    {
	    int nCasterLevel = JXGetCasterLevel(OBJECT_SELF);
	    int nMetaMagic	 = JXGetMetaMagicFeat();
	    int nRandom, nHD, nVisual, bTwoEffects;
	
		if(!MyResistSpell(OBJECT_SELF, oTarget))
		{							
			if (spellsIsTarget(oTarget, SPELL_TARGET_STANDARDHOSTILE, OBJECT_SELF))
			{		
				float fMaxDelay = 0.0f; // ???
			    float fDelay = GetDelayForTarget( oTarget );
				if (fMaxDelay < fDelay)
				{
					fMaxDelay = fDelay;
				}
			
			
				// Do prismatic effects here.
                 nVisual = ApplyPrismaticEffect( Random(PS_EFFECT_COUNT), oTarget);
                 effect eVisual = EffectVisualEffect(nVisual);
                 //Apply the visual effect
                 DelayCommand(fDelay, JXApplyEffectToObject(DURATION_TYPE_INSTANT, eVisual, oTarget));
			}
		}
		
		//Select the next target within the spell shape.
        oTarget = GetNextObjectInShape(SHAPE_SPHERE, RADIUS_SIZE_HUGE, lTarget, TRUE, OBJECT_TYPE_CREATURE | OBJECT_TYPE_DOOR | OBJECT_TYPE_PLACEABLE);
    }
	



	JXPostSpellCastCode();
}