//::///////////////////////////////////////////////
//:: Rainbow Beam
//:: mt_s0_rainbowbeam
//:: Created By: Joshua Kalis (Greg)
//:: Created On: Jan 25, 2008
//:: Description: 
//:: You fire a ray of swirling, multihued light drawn from radiant energies. 
//:: The light's hues wind together but remain independent.
//::	
//:: You must succeed on a ranged touch attack with the ray to strike a target. 
//:: If you hit, the subject is dazzled for 1 minute. The spell also deals 1d12
//:: points of damage per three caster levels (maximum 5d12). A rainbow beam deals
//:: a random type of damage as determined by the following table. If two types of
//:: energy are indicated, rainbow beam deals half its damage from each type of 
//:: energy indicated. Creatures apply energy resistance separately to each type 
//:: of damage.
//::	
//:: 1d8 Color Damage Type
//:: 1 red fire
//:: 2 orange acid
//:: 3 yellow electricity
//:: 4 green magic
//:: 5 blue cold
//:: 6 indigo sonic
//:: 7 violet force
//:: 8 multihued roll twice (ignore further results of 8)
//:://////////////////////////////////////////////

#include "X0_I0_SPELLS"
#include "x2_inc_spellhook" 
#include "cmi_inc_sneakattack"

void main()
{
    if (!X2PreSpellCastCode())
    {	// If code within the PreSpellCastHook (i.e. UMD) reports FALSE, do not run this spell
        return;
    }

	//Declare major variables
	object oCaster = OBJECT_SELF;
	object oTarget = GetSpellTargetObject();
	int nCasterLvl = GetCasterLevel(oCaster);
	
	nCasterLvl = nCasterLvl / 3;
	
	if (nCasterLvl > 5)
		nCasterLvl = 5;

    if (GetHasFeat(5028)) // If have archmage SP+3, add 3 more.
    {
        nCasterLvl = (nCasterLvl + 3);
    }	
    else if (GetHasFeat(5027)) // If have archmage SP+2, add 2 more.
    {
        nCasterLvl = (nCasterLvl + 2);
    }	
    else if (GetHasFeat(5026)) // If have archmage SP+1, add 1 more.
    {
        nCasterLvl = (nCasterLvl + 1);
    }	
	
    if (GetHasFeat(3092)) // If have acidic splatter, add 1 more.
    {
        nCasterLvl = (nCasterLvl + 1);
    }	
    if (GetHasFeat(3093)) // If have clap of thunder, add 1 more.
    {
        nCasterLvl = (nCasterLvl + 1);
    }	
    if (GetHasFeat(3094)) // If have fiery burst, add 1 more.
    {
        nCasterLvl = (nCasterLvl + 1);
    }	
    if (GetHasFeat(3098)) // If have storm bolt, add 1 more.
    {
        nCasterLvl = (nCasterLvl + 1);
    }	
    if (GetHasFeat(3101)) // If have winters blast, add 1 more.
    {
        nCasterLvl = (nCasterLvl + 1);
    }	
				
	int nDamage = d12(nCasterLvl);
		
	effect eVis;	
	int nDamageType;
	int nSpellId = GetSpellId();
	int randomType = d8(1);
		
	if (GetIsObjectValid(oTarget))
	{
		if (spellsIsTarget(oTarget, SPELL_TARGET_STANDARDHOSTILE, oCaster))
		{		
		
			int nRangedTouch = TouchAttackRanged(oTarget);
			if (nRangedTouch != TOUCH_ATTACK_RESULT_MISS)
			{
				if(!MyResistSpell(oCaster, oTarget))
				{								
					if (GetHasFeat(2992,oCaster,TRUE))
						nDamage += 2;
						
					int nMax = (nCasterLvl*8)+2;
					
					nDamage = ApplyMetamagicVariableMods( nDamage, nMax );	
					
					if (nRangedTouch == TOUCH_ATTACK_RESULT_CRITICAL)
						nDamage = nDamage * 2;
						
					if (StringToInt(Get2DAString("cmi_options","Value",CMI_OPTIONS_SneakAttackSpells)))
					{	
						nDamage += EvaluateSneakAttack(oTarget, OBJECT_SELF);	
					}		
					
					int nDmgType = DAMAGE_TYPE_COLD;	
					if (GetHasFeat(FEAT_FROSTMAGE_PIERCING_COLD))
					{
						nDmgType = DAMAGE_TYPE_MAGICAL;
					}	

					switch(randomType) {
						case 1: // fire
								nDamageType	= DAMAGE_TYPE_FIRE;
								eVis = EffectVisualEffect(VFX_HIT_SPELL_FIRE);
							break;
						case 2: // acid
								nDamageType	= DAMAGE_TYPE_ACID;
								eVis = EffectVisualEffect(VFX_HIT_SPELL_ACID);
							break;
						case 3: // electricity
								nDamageType	= DAMAGE_TYPE_ELECTRICAL;
								eVis = EffectVisualEffect(VFX_HIT_SPELL_LIGHTNING);
							break;
						case 4: // magic
								nDamageType	= DAMAGE_TYPE_MAGICAL;
								eVis = EffectVisualEffect(VFX_HIT_SPELL_MAGIC);
							break;
						case 5: // cold
								nDamageType	= nDmgType;
								eVis = EffectVisualEffect(VFX_HIT_SPELL_ICE);
							break;
						case 6: // sonic
								nDamageType	= DAMAGE_TYPE_SONIC;
								eVis = EffectVisualEffect(VFX_HIT_SPELL_SONIC);
							break;
						case 7: // force
								nDamageType	= DAMAGE_TYPE_BLUDGEONING;
								eVis = EffectVisualEffect(VFX_HIT_SPELL_TRANSMUTATION);
							break;
					}
					
					if(randomType != 8) {					
						// Do damage effect.					
						effect eDamage = EffectDamage(nDamage,nDamageType);
						
						//Fire cast spell at event for the specified target
						SignalEvent(oTarget, EventSpellCastAt(OBJECT_SELF, nSpellId));				
		
						//Apply the effects
						ApplyEffectToObject(DURATION_TYPE_INSTANT, eVis, oTarget);
						ApplyEffectToObject(DURATION_TYPE_INSTANT, eDamage, oTarget);
						
						if (GetHasFeat(5212,OBJECT_SELF,TRUE)) // Diabolism
						{
							int nLevelDiabolist = GetLevelByClass(96, OBJECT_SELF);
							if(nLevelDiabolist == 10)
								nDamage = 3;
							else if(nLevelDiabolist == 5)
								nDamage = 2;
							else
								nDamage = 1;	
							
			                effect eDam2 = EffectDamage(nDamage, DAMAGE_TYPE_NEGATIVE);
							ApplyEffectToObject(DURATION_TYPE_INSTANT, eDam2, oTarget);
						}
	
						if (GetHasFeat(5213,OBJECT_SELF,TRUE)) // Vile Diabolism
						{
							nDamage = 1;
			                effect eDam3 = EffectDamage(nDamage, DAMAGE_TYPE_MAGICAL);
							ApplyEffectToObject(DURATION_TYPE_INSTANT, eDam3, oTarget);
						}						
					}
					else
					{
						// Make sure we have two different types of energy 
						// being hurled.
						int randomType1 = d8(1);
						int randomType2 = d8(1);
						if(randomType1 == 8)
							randomType1 = d6(1);
						if(randomType2 == 8)
							randomType2 = d6(1)+1;
						if(randomType1 == randomType2) {
							if(randomType1 == 1)
								randomType2 = randomType2 + d4(1);
							else if(randomType1 == 7)
								randomType2 = randomType2 - d4(1);
						}
						
						// Do first damage type.	
						switch(randomType1) {
							case 1: // fire
									nDamageType	= DAMAGE_TYPE_FIRE;
									eVis = EffectVisualEffect(VFX_HIT_SPELL_FIRE);
								break;
							case 2: // acid
									nDamageType	= DAMAGE_TYPE_ACID;
									eVis = EffectVisualEffect(VFX_HIT_SPELL_ACID);
								break;
							case 3: // electricity
									nDamageType	= DAMAGE_TYPE_ELECTRICAL;
									eVis = EffectVisualEffect(VFX_HIT_SPELL_LIGHTNING);
								break;
							case 4: // magic
									nDamageType	= DAMAGE_TYPE_MAGICAL;
									eVis = EffectVisualEffect(VFX_HIT_SPELL_MAGIC);
								break;
							case 5: // cold
									nDamageType	= nDmgType;
									eVis = EffectVisualEffect(VFX_HIT_SPELL_ICE);
								break;
							case 6: // sonic
									nDamageType	= DAMAGE_TYPE_SONIC;
									eVis = EffectVisualEffect(VFX_HIT_SPELL_SONIC);
								break;
							case 7: // force
									nDamageType	= DAMAGE_TYPE_BLUDGEONING;
									eVis = EffectVisualEffect(VFX_HIT_SPELL_TRANSMUTATION);
								break;
						}
						// Do damage effect.					
						nDamage = nDamage / 2;
						effect eDamage = EffectDamage(nDamage,nDamageType);
						
						//Fire cast spell at event for the specified target
						SignalEvent(oTarget, EventSpellCastAt(OBJECT_SELF, nSpellId));				
		
						//Apply the effects
						ApplyEffectToObject(DURATION_TYPE_INSTANT, eVis, oTarget);
						ApplyEffectToObject(DURATION_TYPE_INSTANT, eDamage, oTarget);
							
						switch(randomType2) {
							case 1: // fire
									nDamageType	= DAMAGE_TYPE_FIRE;
									eVis = EffectVisualEffect(VFX_HIT_SPELL_FIRE);
								break;
							case 2: // acid
									nDamageType	= DAMAGE_TYPE_ACID;
									eVis = EffectVisualEffect(VFX_HIT_SPELL_ACID);
								break;
							case 3: // electricity
									nDamageType	= DAMAGE_TYPE_ELECTRICAL;
									eVis = EffectVisualEffect(VFX_HIT_SPELL_LIGHTNING);
								break;
							case 4: // magic
									nDamageType	= DAMAGE_TYPE_MAGICAL;
									eVis = EffectVisualEffect(VFX_HIT_SPELL_MAGIC);
								break;
							case 5: // cold
									nDamageType	= nDmgType;
									eVis = EffectVisualEffect(VFX_HIT_SPELL_ICE);
								break;
							case 6: // sonic
									nDamageType	= DAMAGE_TYPE_SONIC;
									eVis = EffectVisualEffect(VFX_HIT_SPELL_SONIC);
								break;
							case 7: // force
									nDamageType	= DAMAGE_TYPE_BLUDGEONING;
									eVis = EffectVisualEffect(VFX_HIT_SPELL_TRANSMUTATION);
								break;
						}
						eDamage = EffectDamage(nDamage,nDamageType);
						
						//Fire cast spell at event for the specified target
						SignalEvent(oTarget, EventSpellCastAt(OBJECT_SELF, nSpellId));				
		
						//Apply the effects
						ApplyEffectToObject(DURATION_TYPE_INSTANT, eVis, oTarget);
						ApplyEffectToObject(DURATION_TYPE_INSTANT, eDamage, oTarget);
						
						if (GetHasFeat(5212,OBJECT_SELF,TRUE)) // Diabolism
						{
							int nLevelDiabolist = GetLevelByClass(96, OBJECT_SELF);
							if(nLevelDiabolist == 10)
								nDamage = 3;
							else if(nLevelDiabolist == 5)
								nDamage = 2;
							else
								nDamage = 1;	
							
			                effect eDam2 = EffectDamage(nDamage, DAMAGE_TYPE_NEGATIVE);
							ApplyEffectToObject(DURATION_TYPE_INSTANT, eDam2, oTarget);
						}
	
						if (GetHasFeat(5213,OBJECT_SELF,TRUE)) // Vile Diabolism
						{
							nDamage = 1;
			                effect eDam3 = EffectDamage(nDamage, DAMAGE_TYPE_MAGICAL);
							ApplyEffectToObject(DURATION_TYPE_INSTANT, eDam3, oTarget);
						}																		
					}
				}
			}
		}	
	}			
}