//::///////////////////////////////////////////////
//:: Summon Natures Ally
//:: mt_s0_summoncreature
//:: Created By: Joshua Kalis (Greg)
//:: Created On: Feb 24, 2008
//:://////////////////////////////////////////////
/*
	Based on NWN original summoning spells.

    Carries out the summoning of the appropriate
    creature for the Summon Monster Series of spells
    1 to 9.  Based on alignment now, has multiple options.
*/

void SummonMultiDruid(string sSummon, location lLocation, int nDuration, effect eVis)
{
	object oSummon = CreateObject(OBJECT_TYPE_CREATURE, sSummon, lLocation, TRUE);
	effect eUnsummon = EffectVisualEffect(VFX_IMP_UNSUMMON);

	if (GetHasFeat(FEAT_AUGMENT_SUMMONING))
	{
		effect eStr = EffectAbilityIncrease(ABILITY_STRENGTH, 4);
		effect eCon = EffectAbilityIncrease(ABILITY_CONSTITUTION, 4);
		effect eLink = EffectLinkEffects(eStr, eCon);
		eLink = SupernaturalEffect(eLink);
		ApplyEffectToObject(DURATION_TYPE_PERMANENT, eLink, oSummon);
	}

	ChangeFaction(oSummon, OBJECT_SELF);
	int nHenchies = GetMaxHenchmen();
	SetMaxHenchmen(nHenchies+50);
	AddHenchman(OBJECT_SELF, oSummon);
	SetMaxHenchmen(nHenchies);

	ApplyEffectAtLocation(DURATION_TYPE_INSTANT, eVis, lLocation);

	DelayCommand(RoundsToSeconds(nDuration), RemoveHenchman(OBJECT_SELF, oSummon));
	DelayCommand(RoundsToSeconds(nDuration), DestroyObject(oSummon, 0.1f));
	DelayCommand(RoundsToSeconds(nDuration), ApplyEffectAtLocation(DURATION_TYPE_INSTANT, eUnsummon, GetLocation(oSummon)));

}


effect SetSummonEffect(int nSpellID);
string GetCreature( int nSpellID );
string GetCreatureAnimalDomain( int nSpellID );
int GetEffectID( int nSpellID );


#include "x2_inc_spellhook" 
#include "cmi_ginc_spells"

void mainSpell();
void main()
{
	AssignCommand(JXGetCaster(), mainSpell());
}

void mainSpell()
{
    if (!X2PreSpellCastCode())
    {	// If code within the PreSpellCastHook (i.e. UMD) reports FALSE, do not run this spell
        JXPostSpellCastCode();
        return;
    }

// End of Spell Cast Hook


    //Declare major variables
    int nSpellID = JXGetSpellId();
    int nDuration = JXGetCasterLevel(OBJECT_SELF) + 3;
    effect eSummon = SetSummonEffect(nSpellID);

    //Make metamagic check for extend
    int nMetaMagic = JXGetMetaMagicFeat();
    if (nMetaMagic & METAMAGIC_EXTEND)
    {
        nDuration = nDuration * 2;	//Duration is +100%
    }
    //Apply the VFX impact and summon effect

    JXApplyEffectAtLocation(DURATION_TYPE_TEMPORARY, eSummon, JXGetSpellTargetLocation(), RoundsToSeconds(nDuration));
	DelayCommand(6.0f, BuffSummons(OBJECT_SELF));
	
	JXPostSpellCastCode();
}


effect SetSummonEffect(int nSpellID)
{
 	int nFNF_Effect = GetEffectID( nSpellID );
  
    string sSummon = "c_cat";

	/*
    if(GetHasFeat(FEAT_ANIMAL_DOMAIN_POWER)) //WITH THE ANIMAL DOMAIN
    {
		sSummon = GetCreatureAnimalDomain( nSpellID );
    }
    else  //WITOUT THE ANIMAL DOMAIN
    {
  		sSummon = GetCreatureAnimalDomain( nSpellID );
    }
	*/
	
	sSummon = GetCreatureAnimalDomain( nSpellID );
    effect eSummonedMonster = EffectSummonCreature(sSummon, nFNF_Effect);
    return eSummonedMonster;
}



string GetCreatureAnimalDomain( int nSpellID )
{
	int nRoll = d4();
	string sSummon = "c_cat";
	int pcClass = GetClassByPosition(1, OBJECT_SELF);
	int goodEvil = GetAlignmentGoodEvil(OBJECT_SELF);
	int lawChaos = GetAlignmentLawChaos(OBJECT_SELF);
	
	switch (nSpellID)
	{
	case (2486): // SPELL_SUMMON_CREATURE_0
       {
           sSummon = "c_cat";
       }
	break;
	case (2419): // SPELL_SUMMON_CREATURE_I
       {
	   		// First, get main (first) class.
			if(pcClass == CLASS_TYPE_DRUID) // Druids, use animals
			{
				// Second, get alignment.
				if(goodEvil > 60) // GOOD
	            	sSummon = "c_deermale";
				else if(goodEvil < 40) // EVIL
	            	sSummon = "c_rat";
				else // NEUTRAL
	            	sSummon = "c_badger";
			}
			else if(pcClass == CLASS_TYPE_CLERIC || pcClass == CLASS_TYPE_PALADIN)
			{
				// Second, get alignment.
				if(goodEvil > 60) // GOOD
	            	sSummon = "c_deermale";
				else if(goodEvil < 40) // EVIL
	            	sSummon = "c_weasel";
				else // NEUTRAL
	            	sSummon = "c_badger";
			}
			else if(pcClass == CLASS_TYPE_WIZARD || pcClass == CLASS_TYPE_SORCERER)
			{
				// Second, get alignment.
				if(goodEvil > 60) // GOOD
	            	sSummon = "c_deermale";
				else if(goodEvil < 40) // EVIL
	            	sSummon = "c_bat";
				else // NEUTRAL
	            	sSummon = "c_bird";
			}
			else // Do original or default summons.		
            	sSummon = "c_dogwolf";
       }
	break;
	case (2420): // SPELL_SUMMON_CREATURE_II
       {
	   		// First, get main (first) class.
			if(pcClass == CLASS_TYPE_DRUID) // Druids, use animals
			{
				// Second, get alignment.
				if(goodEvil > 60) // GOOD
	            	sSummon = "c_pixie";
				else if(goodEvil < 40) // EVIL
	            	sSummon = "c_panther";
				else // NEUTRAL
	            	sSummon = "c_beetlebomb";
			}
			else if(pcClass == CLASS_TYPE_CLERIC || pcClass == CLASS_TYPE_PALADIN)
			{
				// Second, get alignment.
				if(goodEvil > 60) {// GOOD
	            	//sSummon = "c_badger";
					int r;
					r = Random(4);
					
					if(r == 3)
						sSummon = "c_elmwatersmall";
					else if(r == 2)
						sSummon = "c_elmfiresmall";
					else if(r == 1)
						sSummon = "c_elmearthsmall";
					else
						sSummon = "c_elmairsmall";
				}
				else if(goodEvil < 40) // EVIL
	            	sSummon = "c_wolverine";
				else // NEUTRAL
	            	sSummon = "c_dogwolf";
			}
			else if(pcClass == CLASS_TYPE_WIZARD || pcClass == CLASS_TYPE_SORCERER)
			{
				// Second, get alignment.
				if(goodEvil > 60) // GOOD
	            	sSummon = "c_snowleopard";
				else if(goodEvil < 40) // EVIL
	            	sSummon = "c_ratdire";
				else { // NEUTRAL
	            	//sSummon = "c_pig";
					int r;
					r = Random(4);
					
					if(r == 3)
						sSummon = "c_elmwatersmall";
					else if(r == 2)
						sSummon = "c_elmfiresmall";
					else if(r == 1)
						sSummon = "c_elmearthsmall";
					else
						sSummon = "c_elmairsmall";
				}
			}
			else // Do original or default summons.		
            	sSummon = "c_badgerdire";
       }
	break;
	case (2421): // SPELL_SUMMON_CREATURE_III
       {
	   		// First, get main (first) class.
			if(pcClass == CLASS_TYPE_DRUID) // Druids, use animals
			{
				// Second, get alignment.
				if(goodEvil > 60) // GOOD
	            	sSummon = "c_dogwolfdire";
				else if(goodEvil < 40) // EVIL
	            	sSummon = "c_werewolf";
				else // NEUTRAL
	            	sSummon = "c_slyph";
			}
			else if(pcClass == CLASS_TYPE_CLERIC || pcClass == CLASS_TYPE_PALADIN)
			{
				// Second, get alignment.
				if(goodEvil > 60) // GOOD
	            	sSummon = "c_celestial_leopard";
				else if(goodEvil < 40) // EVIL
	            	sSummon = "c_imp";
				else // NEUTRAL
	            	sSummon = "c_impice";
			}
			else if(pcClass == CLASS_TYPE_WIZARD || pcClass == CLASS_TYPE_SORCERER)
			{
				// Second, get alignment.
				if(goodEvil > 60) // GOOD
	            	sSummon = "c_badgerdire";
				else if(goodEvil < 40) // EVIL
	            	sSummon = "c_imp";
				else // NEUTRAL
	            	sSummon = "c_impfire";
			}
			else // Do original or default summons.		
            	sSummon = "c_dogwolfdire";
       }
	break;
	case (2422): // SPELL_SUMMON_CREATURE_IV
       {
	   		// First, get main (first) class.
			if(pcClass == CLASS_TYPE_DRUID) // Druids, use animals
			{
				// Second, get alignment.
				if(goodEvil > 60) // GOOD
	            	sSummon = "c_bearblack";
				else if(goodEvil < 40) // EVIL
	            	sSummon = "c_boardire";
				else // NEUTRAL
	            	sSummon = "c_dryad";
			}
			else if(pcClass == CLASS_TYPE_CLERIC || pcClass == CLASS_TYPE_PALADIN)
			{
				// Second, get alignment.
				if(goodEvil > 60) // GOOD
	            	sSummon = "c_wolverinedire";
				else if(goodEvil < 40) // EVIL
	            	sSummon = "c_doghell";
				else // NEUTRAL
	            	sSummon = "c_boardire";
			}
			else if(pcClass == CLASS_TYPE_WIZARD || pcClass == CLASS_TYPE_SORCERER)
			{
				// Second, get alignment.
				if(goodEvil > 60) // GOOD
	            	sSummon = "c_wolverinedire";
				else if(goodEvil < 40) // EVIL
	            	sSummon = "c_doghell";
				else { // NEUTRAL
	            	//sSummon = "c_wolverinedire";
					int r;
					r = Random(4);
					
					if(r == 3)
						sSummon = "c_elmwater";
					else if(r == 2)
						sSummon = "c_elmfire";
					else if(r == 1)
						sSummon = "c_elmearth";
					else
						sSummon = "c_elmair";
				}
			}
			else // Do original or default summons.		
		    	sSummon = "c_boardire";
       }
	break;
	case (2423): // SPELL_SUMMON_CREATURE_V
       {
	   		// First, get main (first) class.
			if(pcClass == CLASS_TYPE_DRUID) // Druids, use animals
			{
				// Second, get alignment.
				if(goodEvil > 60) // GOOD
	            	sSummon = "c_bear";
				else if(goodEvil < 40) // EVIL
	            	sSummon = "c_dogwolfdire";
				else { // NEUTRAL
	            	//sSummon = "c_bear";
					int r;
					r = Random(4);
					
					if(r == 3)
						sSummon = "c_elmwaterlarge";
					else if(r == 2)
						sSummon = "c_elmfirelarge";
					else if(r == 1)
						sSummon = "c_elmearthlarge";
					else
						sSummon = "c_elmairlarge";
				}
			}
			else if(pcClass == CLASS_TYPE_CLERIC || pcClass == CLASS_TYPE_PALADIN)
			{
				// Second, get alignment.
				if(goodEvil > 60) // GOOD
	            	sSummon = "c_boardire";
				else if(goodEvil < 40) // EVIL
	            	sSummon = "c_dogshado";
				else // NEUTRAL
	            	sSummon = "c_bear";
			}
			else if(pcClass == CLASS_TYPE_WIZARD || pcClass == CLASS_TYPE_SORCERER)
			{
				// Second, get alignment.
				if(goodEvil > 60) // GOOD
	            	sSummon = "c_boardire";
				else if(goodEvil < 40) // EVIL
	            	sSummon = "c_dogshado";
				else // NEUTRAL
	            	sSummon = "c_bear";
			}
			else // Do original or default summons.		
            	sSummon = "c_dogshado";
       }
	break;
    case (2424): // SPELL_SUMMON_CREATURE_VI
       {
	   		// First, get main (first) class.
			if(pcClass == CLASS_TYPE_DRUID) // Druids, use animals
			{
				// Second, get alignment.
				if(goodEvil > 60) // GOOD
	            	sSummon = "c_beetlestag";
				else if(goodEvil < 40) // EVIL
	            	sSummon = "c_troll";
				else // NEUTRAL
	            	sSummon = "c_beetlestag";
			}
			else if(pcClass == CLASS_TYPE_CLERIC || pcClass == CLASS_TYPE_PALADIN)
			{
				// Second, get alignment.
				if(goodEvil > 60) // GOOD
	            	sSummon = "c_celestialwolf";
				else if(goodEvil < 40) // EVIL
	            	sSummon = "c_succubus";
				else { // NEUTRAL
	            	//sSummon = "c_beetlestag";
					int r;
					r = Random(4);
					
					if(r == 3)
						sSummon = "c_elmwaterlarge";
					else if(r == 2)
						sSummon = "c_elmfirelarge";
					else if(r == 1)
						sSummon = "c_elmearthlarge";
					else
						sSummon = "c_elmairlarge";
				}
			}
			else if(pcClass == CLASS_TYPE_WIZARD || pcClass == CLASS_TYPE_SORCERER)
			{
				// Second, get alignment.
				if(goodEvil > 60) // GOOD
	            	sSummon = "c_celestialwolf";
				else if(goodEvil < 40) // EVIL
	            	sSummon = "c_succubus";
				else { // NEUTRAL
	            	//sSummon = "c_bear";
					int r;
					r = Random(4);
					
					if(r == 3)
						sSummon = "c_elmwaterlarge";
					else if(r == 2)
						sSummon = "c_elmfirelarge";
					else if(r == 1)
						sSummon = "c_elmearthlarge";
					else
						sSummon = "c_elmairlarge";
				}
			}
			else // Do original or default summons.		
            	sSummon = "c_beetlestag";
       }
	break;
	case (2425): // SPELL_SUMMON_CREATURE_VII
       {
	   		// First, get main (first) class.
			if(pcClass == CLASS_TYPE_DRUID) // Druids, use animals
			{
				// Second, get alignment.
				if(goodEvil > 60) // GOOD
	            	sSummon = "c_dogwolfwin";
				else if(goodEvil < 40) // EVIL
	            	sSummon = "c_umber";
				else // NEUTRAL
	            	sSummon = "c_umber";
			}
			else if(pcClass == CLASS_TYPE_CLERIC || pcClass == CLASS_TYPE_PALADIN)
			{
				// Second, get alignment.
				if(goodEvil > 60) // GOOD
	            	sSummon = "c_dogwolfwin";
				else if(goodEvil < 40) // EVIL
	            	sSummon = "c_erinyes";
				else // NEUTRAL
	            	sSummon = "c_dogwolfwin";
			}
			else if(pcClass == CLASS_TYPE_WIZARD || pcClass == CLASS_TYPE_SORCERER)
			{
				// Second, get alignment.
				if(goodEvil > 60) // GOOD
	            	sSummon = "c_dogwolfwin";
				else if(goodEvil < 40) // EVIL
	            	sSummon = "c_erinyes";
				else // NEUTRAL
	            	sSummon = "c_dogwolfwin";
			}
			else // Do original or default summons.		
            	sSummon = "c_beetlestag";
       }
	break;
	case (2426): // SPELL_SUMMON_CREATURE_VIII
       {
	   		// First, get main (first) class.
			if(pcClass == CLASS_TYPE_DRUID) // Druids, use animals
			{
				// Second, get alignment.
				if(goodEvil > 60) // GOOD
	            	sSummon = "c_celestialbear";
				else if(goodEvil < 40) // EVIL
	            	sSummon = "c_fiendrat9";
				else // NEUTRAL
	            	sSummon = "c_celestialbear";
			}
			else if(pcClass == CLASS_TYPE_CLERIC || pcClass == CLASS_TYPE_PALADIN)
			{
				// Second, get alignment.
				if(goodEvil > 60) // GOOD
	            	sSummon = "c_beardire";
				else if(goodEvil < 40) // EVIL
	            	sSummon = "c_hezrou";
				else // NEUTRAL
	            	sSummon = "c_celestialbear";
			}
			else if(pcClass == CLASS_TYPE_WIZARD || pcClass == CLASS_TYPE_SORCERER)
			{
				// Second, get alignment.
				if(goodEvil > 60) // GOOD
	            	sSummon = "c_beardire";
				else if(goodEvil < 40) // EVIL
	            	sSummon = "c_hezrou";
				else // NEUTRAL
	            	sSummon = "c_celestialbear";
			}
			else // Do original or default summons.		
            	sSummon = "c_celestialbear";
       }
	break;
	case (2427): // SPELL_SUMMON_CREATURE_IX
       {
	   		// First, get main (first) class.
			if(pcClass == CLASS_TYPE_DRUID) // Druids, use animals
			{
				// Second, get alignment.
				if(goodEvil > 60) // GOOD
	            	sSummon = "c_celestialdbear";
				else if(goodEvil < 40) // EVIL
	            	sSummon = "c_felltroll";
				else // NEUTRAL
	            	sSummon = "c_celestialdbear";
			}
			else if(pcClass == CLASS_TYPE_CLERIC || pcClass == CLASS_TYPE_PALADIN)
			{
				// Second, get alignment.
				if(goodEvil > 60) // GOOD
	            	sSummon = "c_planetar";
				else if(goodEvil < 40) // EVIL
	            	sSummon = "c_devilhorn";
				else // NEUTRAL
	            	sSummon = "c_night_hag";
			}
			else if(pcClass == CLASS_TYPE_WIZARD || pcClass == CLASS_TYPE_SORCERER)
			{
				// Second, get alignment.
				if(goodEvil > 60) // GOOD
	            	sSummon = "c_planetar";
				else if(goodEvil < 40) // EVIL
	            	sSummon = "c_devilhorn";
				else // NEUTRAL
	            	sSummon = "c_djinni";
			}
			else // Do original or default summons.		
            	sSummon = "c_celestialdbear";
       }
	break;
	}
	return sSummon;
}


string GetCreature( int nSpellID )
{
	int nRoll = d3();
	string sSummon = "c_chicken";

	switch ( nSpellID )
	{
	case (SPELL_SUMMON_CREATURE_I):
        {
            sSummon = "c_badger";
        }
	break;
	case (SPELL_SUMMON_CREATURE_II):
		{
            sSummon = "c_boar";
        }
	break;
	case (SPELL_SUMMON_CREATURE_III):
        {
            sSummon = "c_dogwolf";
        }
	break;
	case (SPELL_SUMMON_CREATURE_IV):
        {
            sSummon = "c_bear";
        }
	break;
	case (SPELL_SUMMON_CREATURE_V):
        {
            sSummon = "c_doghell";
        }
	break;
	case (SPELL_SUMMON_CREATURE_VI):
        {
            sSummon = "c_bugbear";
        }
	break;
	case (SPELL_SUMMON_CREATURE_VII):
        {
            switch (nRoll)
            {
               case 1:	sSummon = "c_impfire";		break;
               case 2:	sSummon = "c_impice";		break;
               case 3:	sSummon = "c_ratdire";		break;
            }
        }
	break;
	case (SPELL_SUMMON_CREATURE_VIII):
        {
            switch (nRoll)
            {
               case 1:	sSummon = "c_impfire";		break;
               case 2:	sSummon = "c_impice";		break;
               case 3:	sSummon = "c_ratdire";		break;
            }
        }
	break;
	case (SPELL_SUMMON_CREATURE_IX):
        {
            switch (nRoll)
            {
               case 1:	sSummon = "c_impfire";		break;
               case 2:	sSummon = "c_impice";		break;
               case 3:	sSummon = "c_ratdire";		break;
            }
        }
	break;
	}

	return sSummon;
}

int GetEffectID( int nSpellID )
{
	return VFX_HIT_SPELL_SUMMON_CREATURE;
}